Package: textclassificationtutorial
Title: Reproducible Text Classification Workflows
Version: 0.1.2
Authors@R: c(
    person("Vladimer", "Kobayashi", role = c("aut", "cre"),
           email = "vladimer.kobayashi@gmail.com"),
    person("Stefan", "Mol", role = "aut"),
    person("Gabor", "Kismihok", role = "aut")
  )
Description: Dependency-light tools and tutorials for teaching reproducible
    text classification. The package covers HTML text extraction, sentence
    segmentation, text preprocessing, document-term matrices, TF-IDF,
    keyword extraction, cosine similarity, stratified cross-validation,
    classification metrics, and a multinomial Naive Bayes classifier. It 
    modernizes the code accompanying 
    Kobayashi, V. B., Berkers, H. A., Mol, S. T. Kismihok, G., and Den Hartog, D. N. (2017) <doi:10.1177/1094428117719322>
    The package replaces the original scripts in the paper.
License: Apache License (>= 2)
URL: https://github.com/vkobayashi/textclassificationtutorial
BugReports: https://github.com/vkobayashi/textclassificationtutorial/issues
Depends: R (>= 4.1.0)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), xml2
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-08-20 21:22:17 UTC; vladimerkobayashi
Author: Vladimer Kobayashi [aut, cre],
  Stefan Mol [aut],
  Gabor Kismihok [aut]
Maintainer: Vladimer Kobayashi <vladimer.kobayashi@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-26 19:30:02 UTC
