# Generated by roxygen2: do not edit by hand

S3method(predict,text_nb)
S3method(print,text_dtm)
S3method(print,text_nb)
export(classification_metrics)
export(cosine_similarity)
export(document_term_matrix)
export(extract_html_dir)
export(extract_html_text)
export(extract_keywords)
export(f_measure)
export(fit_naive_bayes)
export(preprocess_text)
export(read_label_file)
export(split_sentences)
export(stratified_folds)
export(tf_idf)
