% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dtm.R
\name{tf_idf}
\alias{tf_idf}
\title{Calculate TF-IDF weights}
\usage{
tf_idf(dtm, normalize = c("length", "max", "none"), smooth_idf = TRUE)
}
\arguments{
\item{dtm}{Numeric document-term matrix.}

\item{normalize}{Term-frequency normalization: document length, maximum
frequency, or none.}

\item{smooth_idf}{Logical; use smoothed inverse document frequency?}
}
\value{
A numeric matrix of TF-IDF weights.
}
\description{
Calculate TF-IDF weights
}
