% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/html.R
\name{extract_html_dir}
\alias{extract_html_dir}
\title{Extract text from a directory of HTML files}
\usage{
extract_html_dir(path, pattern = "\\\\.html?$", recursive = FALSE, ...)
}
\arguments{
\item{path}{Directory containing HTML files.}

\item{pattern}{File-name regular expression.}

\item{recursive}{Logical; search recursively?}

\item{...}{Passed to \code{\link[=extract_html_text]{extract_html_text()}}.}
}
\value{
A data frame with \code{document_id}, \code{path}, and \code{text}.
}
\description{
Extract text from a directory of HTML files
}
