% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/evaluation.R
\name{classification_metrics}
\alias{classification_metrics}
\title{Calculate binary classification metrics}
\usage{
classification_metrics(truth, estimate, positive)
}
\arguments{
\item{truth}{Vector of true classes.}

\item{estimate}{Vector of predicted classes.}

\item{positive}{Value identifying the positive class.}
}
\value{
A one-row data frame containing confusion counts, accuracy,
balanced accuracy, precision, recall, specificity, and F1.
}
\description{
Calculate binary classification metrics
}
\examples{
classification_metrics(c("task", "task", "other"), c("task", "other", "other"),
                       positive = "task")
}
