% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/evaluation.R
\name{stratified_folds}
\alias{stratified_folds}
\title{Create stratified cross-validation folds}
\usage{
stratified_folds(y, k = 5L, repeats = 1L, seed = NULL)
}
\arguments{
\item{y}{Class labels.}

\item{k}{Number of folds.}

\item{repeats}{Number of repeated fold sets.}

\item{seed}{Optional random seed. The caller's random-number state is
restored.}
}
\value{
A list of integer test-set indices with class \code{text_folds}.
}
\description{
Create stratified cross-validation folds
}
